#
# spec file for package spec-cleaner
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
# Copyright (c) 2012 Vincent Untz <vuntz@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           spec-cleaner
Version:        0.5.9
Release:        31.1
Summary:        .spec file cleaner
License:        BSD-3-Clause
Group:          Development/Tools/Other
Url:            http://github.com/openSUSE/spec-cleaner
Source0:        https://github.com/openSUSE/%{name}/archive/%{name}-%{version}.tar.gz
BuildRequires:  python
Requires:       python-argparse
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
# This is just for tests
# It is conditional so we built on older distros too
# Drop after 12.2 and older are not targeted here
%if 0%{?suse_version} > 01220
BuildRequires:  python3
%endif

%description
This script cleans spec file according to some arbitrary style guide. The
results it produces should always be checked by someone since it is not and
will never be perfect.

%prep
%setup -q -n %{name}-%{name}-%{version}

%build

%check
make check -j1

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags} \
	LIBEXECDIR=%{_libexecdir} \
	LIBDIR=%{_libdir} \
	SITEDIR=%{python_sitelib}

%files
%defattr(-, root, root)
%{_bindir}/%{name}
%dir %{_libexecdir}/obs/
%dir %{_libexecdir}/obs/service/
%{_libexecdir}/obs/service/clean_spec_file
%{_libexecdir}/obs/service/clean_spec_file.service
%dir %{python_sitelib}/spec_cleaner/
%{python_sitelib}/spec_cleaner/__init__.py*
%{python_sitelib}/spec_cleaner/fileutils.py*
%{python_sitelib}/spec_cleaner/rpmbuild.py*
%{python_sitelib}/spec_cleaner/rpmcheck.py*
%{python_sitelib}/spec_cleaner/rpmcleaner.py*
%{python_sitelib}/spec_cleaner/rpmcopyright.py*
%{python_sitelib}/spec_cleaner/rpmdescription.py*
%{python_sitelib}/spec_cleaner/rpmexception.py*
%{python_sitelib}/spec_cleaner/rpmfiles.py*
%{python_sitelib}/spec_cleaner/rpminstall.py*
%{python_sitelib}/spec_cleaner/rpmpreamble.py*
%{python_sitelib}/spec_cleaner/rpmprep.py*
%{python_sitelib}/spec_cleaner/rpmprune.py*
%{python_sitelib}/spec_cleaner/rpmregexp.py*
%{python_sitelib}/spec_cleaner/rpmscriplets.py*
%{python_sitelib}/spec_cleaner/rpmsection.py*
%dir %{_datadir}/%{name}/
%{_datadir}/%{name}/excludes-bracketing.txt
%{_datadir}/%{name}/licenses_changes.txt
%{_datadir}/%{name}/pkgconfig_conversions.txt

%changelog
* Tue Jul  8 2014 tchvatal@suse.com
- Version bump to 0.5.9:
  * Fix parsing %%endif #comment
  * Fix parsing %%if rigth after %%clean section
* Mon Jun 23 2014 tchvatal@suse.com
- Version bump to 0.5.8:
  * brown paperbag release fixing tests on py3.
* Mon Jun 23 2014 tchvatal@suse.com
- Version bump to 0.5.7:
  * Updates about smp_mflags parsing
  * makeinstall macro replacing improvements.
* Sat May 10 2014 tchvatal@suse.com
- Version bump to 0.5.6:
  * Few minor fixes as reported on github.
* Fri Apr  4 2014 tchvatal@suse.com
- Version bump to 0.5.5:
  * Few minor fixes as reported on github tracker.
* Mon Feb  3 2014 tchvatal@suse.com
- Version bump to 0.5.4:
  * plenty of bugfixes regarding to spec parsing as they were
    reported on github
  * add more exceptions on adding curly brackets
  * update licenses list to the latest.
* Tue Jan 14 2014 tchvatal@suse.com
- Add comment on py3 conditional and depend on python-argparse
* Thu Jan  9 2014 tchvatal@suse.com
- Version bump to 0.5.3:
  + Various parser fixes and extended testsuite coverage
    thanks to reports from packagers team.
* Wed Dec  4 2013 tchvatal@suse.com
- Version bump to 0.5.2:
  + Fixes issues found while parsing libreoffice
  + Fixes issues 4 and 3 on github
* Tue Dec  3 2013 tchvatal@suse.com
- Version bump to 0.5.1:
  + Fixes the conditionals placement and makes all tests pass.
* Fri Nov 29 2013 tchvatal@suse.com
- Version bump to 0.4.2:
  + fix inlining
  + fix service shell script
  + rename obs service to different from format_spec_file
* Mon Nov 25 2013 tchvatal@suse.com
- Fix build on fedora as they bytecompile the py
* Mon Nov 25 2013 tchvatal@suse.com
- Version bump to 0.4.1
  + Fixes to actually be able to parse own specfile.
* Mon Nov 25 2013 tchvatal@suse.com
- Version bump to 0.4.0:
  + Add extensive testsuite
  + Split the code for readability purposes
  + Mimic all the functionality from prep_spec
  + Provide and obsolete obs-service-format_spec_file
* Thu Mar 22 2012 saschpe@suse.de
- Set license to SPDX style (BSD-3-Clause)
* Mon Sep 12 2011 prusnak@opensuse.org
- synchronize obs and git changes
* Thu Jul 14 2011 giecrilj@stegny.2a.pl
- better usage message
* Mon May  2 2011 vuntz@opensuse.org
- Update to version 0.2:
  + Handle suse_version
  + Do not check for AutoReqProv in %%install
  + Replace %%makeinstall by %%make_install
  + Reformat versioned package names too
  + Remove #usedforbuild
  + Replace Patch: with Patch0: (and %%patch with %%patch0)
  + Change default .spec headers to not include any license
  + Replace some package names with pkgconfig()-style names
  + Add --diff and --diff-prog options
  + Put brackets around %%name, %%version, %%release, ...
  + Update url for PATCH-MISSING-TAGw
  + Cut summary after the first dot
  + Add FDL licenses
  + Add .spec extension to spec files created by script
  + Put pkgconfig()-style package names at the end of their list
  + Code improvements
* Mon Dec  6 2010 prusnak@opensuse.org
- update to newer snapshot (1fb8c6db)
  - --diff and --diff-prog options by Petr Uzel
* Thu Sep 30 2010 vuntz@opensuse.org
- Initial package (version 0.1)
